@@ -20,7 +20,7 @@ class IsassEventHandler(FileSystemEventHandler):
         self.outfiles = outfiles
         self.dirs = dirs
         self.lib_dirs = lib_dirs if lib_dirs else []
-        self.source_files = get_source_files(self.dirs,extension=self.extension)
+        self.source_files = get_source_files(self.dirs, extensions=self.extension)
         if files:
             self.source_files += files
         super(FileSystemEventHandler, self).__init__()
@@ -35,7 +35,7 @@ class IsassEventHandler(FileSystemEventHandler):
             compiler = SassCompiler(lib_dirs=lib_dirs)
             for sf in self.source_files:
                 #print "Reading %s" % os.path.abspath(sf)
-                compiler.read_file(sf)
+                compiler.read_sass_file(sf)
 
 
             normal_output = compiler.get_css()
@@ -77,6 +77,28 @@ class IsassEventHandler(FileSystemEventHandler):
             self.write_out()
 
 
+class ManifestEventHandler(FileSystemEventHandler):
+    extension = '.sass,.scss'
+
+    def __init__(self, manifest, taskname):
+        self.manifest = manifest
+        self.taskname = taskname
+        super(FileSystemEventHandler, self).__init__()
+
+    def write_out(self):
+        self.manifest.write_outputs(self.taskname)
+
+    def on_any_event(self, event):
+        paths = []
+        if hasattr(event, 'src_path'):
+            paths += split_paths(event.src_path)
+        if hasattr(event, 'dest_path'):
+            paths += split_paths(event.dest_path)
+
+        if self.manifest.is_paths_in_task(self.taskname, paths):
+            self.write_out()
+
+
 class SassObserver(Observer):
 
     def add_output(self, outfiles, dirs=None, files=None, lib_dirs=None):
@@ -112,15 +134,7 @@ class SassObserver(Observer):
     def add_manifest(self, manifest):
         manifest = Manifest(manifest)
         for taskname in manifest.get_task_names():
-            task = manifest[taskname]
-            dirs = []
-            files = []
-            for s in task.sources:
-                if os.path.isfile(s):
-                    files.append(s)
-                else:
-                    dirs.append(s)
-            self.add_output(outfiles=task.output,
-                            dirs=dirs,
-                            files=files,
-                            lib_dirs=task.libdirs)
+            handler = ManifestEventHandler(manifest, taskname)
+            watch_dirs = manifest.get_watch_dirs(taskname)
+            for d in watch_dirs:
+                self.schedule(handler, d, recursive=False)
\ No newline at end of file
